
import { Link } from 'react-router-dom';
import { ArrowRight } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { useEffect, useState } from 'react';
import { EnergieCheckLogo } from '@/components/EnergieCheckLogo';

export const Hero = () => {
  const heroImagePath = "/lovable-uploads/eb2a7ee9-48af-4ba3-845a-1e47bd2fcd14.png";
  const [imageLoaded, setImageLoaded] = useState(false);

  useEffect(() => {
    // Preload the hero image
    const preloadImage = new Image();
    preloadImage.src = heroImagePath;
    preloadImage.onload = () => setImageLoaded(true);
  }, []);

  return <div className="relative w-full">
      <div className="absolute inset-0 z-0">
        <img 
          src={heroImagePath} 
          alt="Energieeffizientes Haus mit Solarpanels" 
          className={`w-full h-full object-cover transition-opacity duration-300 ${imageLoaded ? 'opacity-100' : 'opacity-0'}`}
          loading="eager"
          fetchPriority="high"
          decoding="async"
          sizes="100vw"
          onError={e => {
            const target = e.target as HTMLImageElement;
            console.log("Hero image failed to load:", target.src);
            target.style.display = "none";
            target.parentElement!.style.backgroundColor = "#1a2e35";
          }} 
        />
        <div className="absolute inset-0 bg-gradient-to-r from-black/60 to-transparent"></div>
      </div>
      
      <div className="container mx-auto relative z-10">
        <header className="flex justify-between items-center pt-8 px-4">
          <EnergieCheckLogo />
          <nav className="hidden md:flex items-center space-x-8">
            <Link to="/" className="text-white/90 hover:text-white text-sm font-medium">
              Home
            </Link>
            <Link to="/blog" className="text-white/90 hover:text-white text-sm font-medium">
              Blog
            </Link>
            <Link to="/quick-check">
              <Button variant="moss" size="default">
                Energie-Check starten
              </Button>
            </Link>
          </nav>
        </header>

        <div className="py-20 md:py-32 px-4">
          <div className="max-w-2xl text-left space-y-6">
            <h1 className="text-4xl sm:text-5xl md:text-6xl font-bold tracking-tight leading-tight text-white">Spare Energie.<br />
Nutze Förderungen. Modernisiere richtig.</h1>
            
            <p className="text-lg md:text-xl text-white/90">Unser Tool analysiert dein Gebäudeprofil in unter 2 Minuten – und zeigt dir, wie du dir staatliche Förderungen von bis zu 24.000 € sichern kannst. Kostenlos, datengestützt und sofort als PDF.</p>

            <div className="flex flex-wrap gap-3 mt-2">
              {[{
              icon: <ArrowRight className="h-4 w-4 text-moss-dark" />,
              text: "Individuelle Einschätzung"
            }, {
              icon: <ArrowRight className="h-4 w-4 text-moss-dark" />,
              text: "Fördercheck"
            }, {
              icon: <ArrowRight className="h-4 w-4 text-moss-dark" />,
              text: "Sofortiges Ergebnis"
            }].map((benefit, i) => <div key={i} className="flex items-center gap-1.5 text-sm bg-white/50 backdrop-blur-sm px-3 py-1 rounded-full">
                  {benefit.icon}
                  <span className="text-foreground/90">{benefit.text}</span>
                </div>)}
            </div>
            
            <div className="flex flex-col sm:flex-row gap-4 mt-4">
              <Link to="/quick-check">
                <Button size="lg" className="bg-moss hover:bg-moss-dark text-white gap-2 px-8 py-6 text-base rounded-xl shadow-sm">
                  Energie-Check starten
                  <ArrowRight className="h-4 w-4" />
                </Button>
              </Link>
            </div>
            
            <div className="flex items-center gap-2 text-white/90 mt-2">
              <span className="text-sm">1000+ Nutzer:innen haben bereits den EnergieCheck genutzt</span>
            </div>
          </div>
        </div>
      </div>
    </div>;
};
